@@ -11,6 +11,10 @@
 ##' over the M replications of the Monte Carlo scheme described in \code{survfitjmcs}.
 ##' @param conf.int logical; if TRUE, then a pointwise confidence interval is included in the plot. Default is TRUE.
 ##' @param include.y include longitudinal responses of this subject versus time. Default is FALSE.
+##' @param xlab X axis label.
+##' @param ylab Y axis label.
+##' @param xlim X axis support.
+##' @param ylim Y axis support.
 ##' @param ... further arguments passed to or from other methods.
 ##' @return plots of conditional probabilities over different pre-specified time points for subjects. 
 ##' If single failure type, then survival probabilities will be returned. 
@@ -43,7 +47,8 @@
 ##' @export
 ##' 
 plot.survfitjmcs <- function (x, estimator = c("both", "mean", "median"), 
-                            conf.int = TRUE, include.y = FALSE, ...) {
+                            conf.int = TRUE, include.y = FALSE, xlab = NULL, ylab = NULL, 
+                            xlim = NULL, ylim = NULL, ...) {
   
   if (!inherits(x, "survfitjmcs"))
     stop("Use only with 'survfitjmcs' xs.\n")
@@ -51,8 +56,9 @@ plot.survfitjmcs <- function (x, estimator = c("both", "mean", "median"),
   if (x$simulate) {
     if (!x$CompetingRisk) {
       which = 1:nrow(x$Last.time)
-      ylim <- c(0, 1)
-      
+      if (is.null(ylim)) ylim <- c(0, 1)
+      if (is.null(xlab)) xlab = "Time"
+      if (is.null(ylab)) ylab = "Longitudinal ouctome"
       ask = (prod(par("mfcol")) < length(which))
       show <- rep(TRUE, length(which))
       return = FALSE
@@ -72,22 +78,23 @@ plot.survfitjmcs <- function (x, estimator = c("both", "mean", "median"),
           probmedian <- c(1, 1, x$Pred[[i]][, 3])
           if (estimator == "both") {
             if (!include.y) {
-              plot(times, probmean, xlab = "Time", ylab = expression(paste("Pr(", T[i] >= u, " | ", T[i] > s, 
-                                                                           ", ", y[i]^(s), ", ",  Psi,")", sep = " ")), 
+              plot(times, probmean, xlab = xlab, ylab = ylab, 
                    main = paste("Subject", x$Last.time[i, 1], sep = " "), col = "red", type = "l", ylim = ylim)
               lines(times, probmedian, col = "green", type = "l")
               segments(x0 = as.numeric(x$Last.time[i, 2]), x1 = as.numeric(x$Last.time[i, 2]), y0 = -1,
                        y1 = 1,
                        lwd = 1)
             } else {
-              plot(x$y.obs[[i]][, 1], x$y.obs[[i]][, 2], xlim = c(0, max(x$Pred[[i]][, 1])), axes = TRUE, xlab = "Time", 
+              if (is.null(xlim)) xlim <- c(0, max(x$Pred[[i]][, 1]))
+              plot(x$y.obs[[i]][, 1], x$y.obs[[i]][, 2], xlim = xlim, ylim = c(110, 170), axes = TRUE, xlab = xlab, 
                    ylab = "", type = "p", pch = 8)
-              title(ylab = "Longitudinal outcome", line=2.5)
+              title(ylab = ylab, line=2.5)
               par(new = TRUE)    
               plot(times, probmean, xlab = "", ylab = "", 
-                   main = paste("Subject", x$Last.time[i, 1], sep = " "), col = "red", type = "l", ylim = ylim, axes = FALSE)
+                   main = paste("Subject", x$Last.time[i, 1], sep = " "), xlim = xlim, col = "red", type = "l", ylim = ylim, axes = FALSE)
               axis(side = 4, at = pretty(range(c(0, 1))), line = 0) 
-              mtext(expression(paste("Pr(", T[i] >= u, " | ", T[i] > s, ", ", y[i]^(s), ", ",  Psi,")", sep = " ")), side = 4, line = 2.5)
+              mtext(expression(paste("Pr(", T[i] >= u, " | ", T[i] > s, 
+                                     ", ", y[i]^(s), ", ",  Psi,")", sep = " ")), side = 4, line = 2.5)
               lines(times, probmedian, col = "green", type = "l")
               segments(x0 = as.numeric(x$Last.time[i, 2]), x1 = as.numeric(x$Last.time[i, 2]), y0 = -1,
                        y1 = 1,
