@@ -11,8 +11,9 @@
 print.survfitjmcs <- function (x, ...) {
   if (!inherits(x, "survfitjmcs"))
     stop("Use only with 'survfitjmcs' xs.\n")
-  
-  cat("\nPrediction of Conditional Probabilities of Event\n\tbased on", x$M, "Monte Carlo samples\n\n")
+
+  if (x$simulate) {
+    cat("\nPrediction of Conditional Probabilities of Event\n\tbased on", x$M, "Monte Carlo samples\n\n")
     f <- function (d, t) {
       a <- matrix(1, nrow = 1, ncol = 5)
       a[1, 1] <- t 
@@ -23,23 +24,26 @@ print.survfitjmcs <- function (x, ...) {
     }
     
     f.CR <- function (d, t) {
-        a <- matrix(0, nrow = 1, ncol = 5)
-        a[1, 1] <- t 
-        a <- as.data.frame(a)
-        
-        colnames(a) <- colnames(d[[1]])
-        for (i in 1:2) {
-          d[[i]] <- rbind(a, d[[i]])
-        }
-        d
+      a <- matrix(0, nrow = 1, ncol = 5)
+      a[1, 1] <- t 
+      a <- as.data.frame(a)
+      
+      colnames(a) <- colnames(d[[1]])
+      for (i in 1:2) {
+        d[[i]] <- rbind(a, d[[i]])
+      }
+      d
     }
     x$Last.time <- as.data.frame(x$Last.time)
     if (!x$CompetingRisk) {
       print(mapply(f, x$Pred, x$Last.time[, 2], SIMPLIFY = FALSE))
-      invisible(x)
     } else {
       print(mapply(f.CR, x$Pred, x$Last.time[, 2], SIMPLIFY = FALSE))
-      invisible(x)
-      }
-
+    }
+  } else {
+    cat("\nPrediction of Conditional Probabilities of Event\nbased on the Guass-Hermite quadrature rule with", x$quadpoint,
+        "quadrature points\n(Confidence interval not available)\n")
+    print(x$Pred)
+  }
+  invisible(x)
   }
\ No newline at end of file
